@@ -1,6 +1,6 @@
 from deap import creator, base
 
-creator.create("Fitness", base.Fitness, weights=(1.0, 1.0))
+creator.create("Fitness", base.Fitness, weights=(-1.0, -1.0, -1.0))
 creator.create("KolmogorovFitness", base.Fitness, weights=(1.0,))
 
 creator.create("Individual", list, fitness=creator.Fitness)
